@@ -17,7 +17,7 @@
  * GNU Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 
@@ -52,7 +52,7 @@ class KGAPIDRIVE_EXPORT PermissionDeleteJob :  KGAPI2::DeleteJob
     explicit PermissionDeleteJob(const QString &fileId,
                                  const QStringList &permissionsIds,
                                  const AccountPtr &account, QObject *parent = nullptr);
-    virtual ~PermissionDeleteJob();
+    ~PermissionDeleteJob() override;
 
   protected:
     void start() override;
